package com.hmall.item.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hmall.api.dto.ItemDTO;
import com.hmall.api.dto.OrderDetailDTO;
import com.hmall.common.exception.BizIllegalException;

import com.hmall.common.utils.BeanUtils;
import com.hmall.item.domain.po.Item;
import com.hmall.item.mapper.ItemMapper;
import com.hmall.item.service.IItemService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collection;
import java.util.Collections;
import java.util.List;

/**
 * <p>
 * 商品表 服务实现类
 * </p>
 *
 * @author 虎哥
 */
@Service
public class ItemServiceImpl extends ServiceImpl<ItemMapper, Item> implements IItemService {

    @Override
    @Transactional
    public void deductStock(List<OrderDetailDTO> items) {
        String sqlStatement = "com.hmall.item.mapper.ItemMapper.updateStock";
        boolean r = false;
        try {
            r = executeBatch(items, (sqlSession, entity) -> sqlSession.update(sqlStatement, entity));
        } catch (Exception e) {
            throw new BizIllegalException("更新库存异常，可能是库存不足!", e);
        }
        if (!r) {
            throw new BizIllegalException("库存不足！");
        }
    }

    @Override
    public List<ItemDTO> queryItemByIds(Collection<Long> ids) {
        // 1. 防空：参数为 null 或 空集合，直接返回空列表
        if (ids == null || ids.isEmpty()) {
            return Collections.emptyList();
        }

        List<Item> items;
        try {
            // 2. 真正去查
            items = listByIds(ids);
        } catch (Exception e) {
            // 3. 捕获底层任何异常，记录并返回空列表
            System.out.println("no");
            return Collections.emptyList();
        }

        // 4. 再防空：数据库里一个都没查到，也返回空
        if (items == null || items.isEmpty()) {
            return Collections.emptyList();
        }

        // 5. 正常转换
        return BeanUtils.copyList(items, ItemDTO.class);
    }

    @Override
    @Transactional
    public void restoreStock(List<OrderDetailDTO> items) {
        String sqlStatement = "com.hmall.item.mapper.ItemMapper.restoreStock";
        boolean r = false;

        try {
            r = executeBatch(items, (sqlSession, entity) ->
                    sqlSession.update(sqlStatement, entity));
        } catch (Exception e) {
            throw new BizIllegalException("恢复库存异常，可能出现业务故障！", e);
        }

        if (!r) {
            throw new BizIllegalException("恢复库存失败！");
        }
    }
}
